@@ -2,12 +2,14 @@
 # DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains certain
 # rights in this software.
 
+from __future__ import division
+
 def show(canvas, title="Toyplot Figure"):
   """Display a canvas in a web browser.
 
   Parameters
   ----------
-  canvas: :class:`toyplot.Canvas`
+  canvas: :class:`toyplot.canvas.Canvas`
     The canvas to be displayed.
 
   title: string, optional
