@@ -3,6 +3,8 @@
 # rights in this software.
 
 from __future__ import absolute_import
+from __future__ import division
+
 
 import cairo
 import toyplot.cairo
@@ -16,7 +18,7 @@ def render(canvas, fobj, width=None, height=None, scale=None):
 
   Parameters
   ----------
-  canvas: :class:`toyplot.Canvas`
+  canvas: :class:`toyplot.canvas.Canvas`
     Canvas to be rendered.
   fobj: file-like object or string
     The file to write.  Use a string filepath to write data directly to disk.
