@@ -3,13 +3,15 @@
 # rights in this software.
 
 from __future__ import absolute_import
+from __future__ import division
+
 
 def show(canvas, title="Toyplot Figure"):
   """Display a canvas in a web browser.
 
   Parameters
   ----------
-  canvas: :class:`toyplot.Canvas`
+  canvas: :class:`toyplot.canvas.Canvas`
     The canvas to be displayed.
 
   title: string, optional
